@@ -35,7 +35,12 @@ use OpenGL::List                   ();
 use SDL::Tutorial::3DWorld::Asset  ();
 use SDL::Tutorial::3DWorld::OpenGL ();
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
+
+# Global Model Cache.
+# Since there are currently no optional model settings and model
+# objects are immutable, we can do a simple file-based key for models.
+our %CACHE = ();
 
 
 
@@ -48,6 +53,11 @@ sub new {
 	my $class = shift;
 	my $self  = bless { @_ }, $class;
 
+	# Make sure the filename is absolute so we have consistent keys
+	# for the global texture cache. Return from the cache if we can.
+	my $key = File::Spec->rel2abs( $self->file );
+	return $CACHE{$key} if $CACHE{$key};
+
 	# Check param
 	my $file  = $self->file;
 	unless ( -f $file ) {
@@ -66,6 +76,9 @@ sub new {
 		die "Missing or invalid asset";
 	}
 
+	# Save the new model to the global cache
+	$CACHE{$key} = $self;
+
 	return $self;
 }
 
@@ -90,9 +103,11 @@ sub list {
 
 sub init {
 	my $self   = shift;
-	my $handle = IO::File->new( $self->file, 'r' );
-	$self->{list} = $self->parse( $handle );
-	$handle->close;
+	unless ( defined $self->{list} ) {
+		my $handle = IO::File->new( $self->file, 'r' );
+		$self->{list} = $self->parse( $handle );
+		$handle->close;
+	}
 	return 1;
 }
 
